package com.miya.fastcashier.net

import android.util.Log
import com.miya.fastcashier.beans.SelfCashierAccountInfo
import com.miya.fastcashier.beans.LoginRequest;
import com.miya.fastcashier.net.BaseResult
import com.miya.fastcashier.net.MiyaHttpLoggingInterceptor
import com.miya.fastcashier.utils.manage.AccountPasswordManageKit
import okhttp3.OkHttpClient
import okhttp3.logging.HttpLoggingInterceptor
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import retrofit2.http.Body
import retrofit2.http.POST


class ApiRequest private constructor() {

    companion object {

        private const val BASE_URL = "https://hhms.miyapay.com/"
        private var apiService: ApiService? = null
        private var sInstance: ApiRequest? = null

        @Synchronized
        fun getInstance(): ApiRequest {
            if (null == sInstance) {
                sInstance = ApiRequest()
            }
            return sInstance!!
        }

        private fun getApiService(): ApiService {
            if (null == apiService) {
                val httpLoggingInterceptor =
                    MiyaHttpLoggingInterceptor {
                        Log.e("####", it)
                    }.apply { level = MiyaHttpLoggingInterceptor.Level.BODY }

                val client = OkHttpClient.Builder()
                    .addInterceptor(httpLoggingInterceptor)
                    .build()

                val retrofit = Retrofit.Builder()
                    .baseUrl(BASE_URL)
                    .client(client)
                    .addConverterFactory(GsonConverterFactory.create())
                    .build()

                apiService = retrofit.create(ApiService::class.java)
            }

            return apiService!!
        }

        fun getBaseUrl(): String {
            return BASE_URL
        }
    }

    fun login(
        loginRequest: LoginRequest,
        commonCallback: CommonCallback<SelfCashierAccountInfo>
    ) {
        getApiService().login(loginRequest).enqueue(commonCallback)
    }
}